==> tracker-2.99.2.tar.xz: tracker-2.99.2/src/libtracker-sparql/tracker-sparql.h <==
/*
 * Copyright (C) 2011, Nokia <ivan.frade@nokia.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA.
 */

#ifndef __LIBTRACKER_SPARQL_H__
#define __LIBTRACKER_SPARQL_H__

#define __LIBTRACKER_SPARQL_INSIDE__

#include <libtracker-sparql/tracker-version.h>
#include <libtracker-sparql/tracker-connection.h>
#include <libtracker-sparql/tracker-cursor.h>
#include <libtracker-sparql/tracker-endpoint.h>
#include <libtracker-sparql/tracker-endpoint-dbus.h>
#include <libtracker-sparql/tracker-version.h>
#include <libtracker-sparql/tracker-ontologies.h>
#include <libtracker-sparql/tracker-resource.h>
#include <libtracker-sparql/tracker-statement.h>
#include <libtracker-sparql/tracker-notifier.h>
#include <libtracker-sparql/tracker-sparql-enum-types.h>
#include <libtracker-sparql/tracker-utils.h>

#undef __LIBTRACKER_SPARQL_INSIDE__

#endif /* __LIBTRACKER_SPARQL_H__ */

==> tracker-3.3.0.rc.tar.xz: tracker-3.3.0.rc/src/libtracker-sparql/tracker-sparql.h <==
/*
 * Copyright (C) 2011, Nokia <ivan.frade@nokia.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA.
 */

#ifndef __LIBTRACKER_SPARQL_H__
#define __LIBTRACKER_SPARQL_H__

#define __LIBTRACKER_SPARQL_INSIDE__

#include <libtracker-sparql/tracker-version-generated.h>
#include <libtracker-sparql/tracker-version.h>
#include <libtracker-sparql/tracker-error.h>
#include <libtracker-sparql/tracker-connection.h>
#include <libtracker-sparql/tracker-batch.h>
#include <libtracker-sparql/tracker-cursor.h>
#include <libtracker-sparql/tracker-endpoint.h>
#include <libtracker-sparql/tracker-endpoint-dbus.h>
#include <libtracker-sparql/tracker-endpoint-http.h>
#include <libtracker-sparql/tracker-version.h>
#include <libtracker-sparql/tracker-ontologies.h>
#include <libtracker-sparql/tracker-resource.h>
#include <libtracker-sparql/tracker-statement.h>
#include <libtracker-sparql/tracker-notifier.h>
#include <libtracker-sparql/tracker-sparql-enum-types.h>
#include <libtracker-sparql/tracker-utils.h>

#undef __LIBTRACKER_SPARQL_INSIDE__

#endif /* __LIBTRACKER_SPARQL_H__ */
